@@ -1,3 +1,5 @@
+"""Functions that will be useful irrespective of backend."""
+
 import warnings
 from collections.abc import Callable, Iterable
 
@@ -10,9 +12,9 @@ from matplotlib.pyplot import close, subplots
 from matplotlib.widgets import LassoSelector
 from numpy import asanyarray, asarray, max, min, swapaxes
 
+from .controller import gogogo_controls, prep_scalars
 from .helpers import *
 from .utils import figure, ioff, nearest_idx
-from .controller import gogogo_controls, prep_scalars
 from .xarray_helpers import get_hs_axes, get_hs_extent, get_hs_fmts
 
 # functions that are methods
@@ -376,6 +378,9 @@ class image_segmenter:
         mask_colors=None,
         mask_alpha=0.75,
         lineprops=None,
+        lasso_mousebutton="left",
+        pan_mousebutton="middle",
+        ax=None,
         figsize=(10, 10),
         **kwargs,
     ):
@@ -398,8 +403,15 @@ class image_segmenter:
         lineprops : dict, default: None
             lineprops passed to LassoSelector. If None the default values are:
             {"color": "black", "linewidth": 1, "alpha": 0.8}
+        lasso_mousebutton : str, or int, default: "left"
+            The mouse button to use for drawing the selecting lasso.
+        pan_mousebutton : str, or int, default: "middle"
+            The button to use for `~mpl_interactions.generic.panhandler`. One of 'left', 'middle' or
+            'right', or 1, 2, 3 respectively.
+        ax : `matplotlib.axes.Axes`, optional
+            The axis on which to plot. If *None* a new figure will be created.
         figsize : (float, float), optional
-            passed to plt.figure
+            passed to plt.figure. Ignored if *ax* is given.
         **kwargs
             All other kwargs will passed to the imshow command for the image
         """
@@ -435,16 +447,28 @@ class image_segmenter:
                 self._overlay[idx] = [0, 0, 0, 0]
             else:
                 self._overlay[idx] = self.mask_colors[i - 1]
-        with ioff:
-            self.fig = figure(figsize=figsize)
-            self.ax = self.fig.gca()
-            self.displayed = self.ax.imshow(self._img, **kwargs)
-            self._mask = self.ax.imshow(self._overlay)
+        if ax is not None:
+            self.ax = ax
+            self.fig = self.ax.figure
+        else:
+            with ioff:
+                self.fig = figure(figsize=figsize)
+                self.ax = self.fig.gca()
+        self.displayed = self.ax.imshow(self._img, **kwargs)
+        self._mask = self.ax.imshow(self._overlay)
 
         if lineprops is None:
             lineprops = {"color": "black", "linewidth": 1, "alpha": 0.8}
         useblit = False if "ipympl" in get_backend().lower() else True
-        self.lasso = LassoSelector(self.ax, self._onselect, lineprops=lineprops, useblit=useblit)
+        button_dict = {"left": 1, "middle": 2, "right": 3}
+        if isinstance(pan_mousebutton, str):
+            pan_mousebutton = button_dict[pan_mousebutton.lower()]
+        if isinstance(lasso_mousebutton, str):
+            lasso_mousebutton = button_dict[lasso_mousebutton.lower()]
+
+        self.lasso = LassoSelector(
+            self.ax, self._onselect, lineprops=lineprops, useblit=useblit, button=lasso_mousebutton
+        )
         self.lasso.set_visible(True)
 
         pix_x = np.arange(self._img.shape[0])
@@ -452,7 +476,7 @@ class image_segmenter:
         xv, yv = np.meshgrid(pix_y, pix_x)
         self.pix = np.vstack((xv.flatten(), yv.flatten())).T
 
-        self.ph = panhandler(self.fig)
+        self.ph = panhandler(self.fig, button=pan_mousebutton)
         self.disconnect_zoom = zoom_factory(self.ax)
         self.current_class = 1
         self.erasing = False
@@ -517,7 +541,7 @@ def hyperslicer(
         scalar data to colors. This parameter is ignored for RGB(A) data.
         forwarded to matplotlib
     norm : `~matplotlib.colors.Normalize`, optional
-        The `.Normalize` instance used to scale scalar data to the [0, 1]
+        The `~matplotlib.colors.Normalize` instance used to scale scalar data to the [0, 1]
         range before mapping to colors using *cmap*. By default, a linear
         scaling mapping the lowest value to 0 and the highest to 1 is used.
         This parameter is ignored for RGB(A) data.
@@ -545,11 +569,13 @@ def hyperslicer(
         Whether to attach an ipywidgets.Play widget to any sliders that get created.
         If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
         want to attach play buttons too.
-            - None: no sliders
-            - True: sliders on the lft
-            - False: no sliders
-            - 'left': sliders on the left
-            - 'right': sliders on the right
+
+        - None: no sliders
+        - True: sliders on the lft
+        - False: no sliders
+        - 'left': sliders on the left
+        - 'right': sliders on the right
+
     is_color_image : boolean
         If True, will treat the last 3 dimensions as comprising a color images and will only set up sliders for the first arr.ndim - 3 dimensions.
     controls : mpl_interactions.controller.Controls
