@@ -12,11 +12,11 @@ try:
 except ImportError:
     pass
 from matplotlib import get_backend
-from matplotlib.pyplot import axes, gca, gcf, figure
+from matplotlib.pyplot import axes, figure, gca, gcf
 from numpy.distutils.misc_util import is_sequence
 
-from .widgets import RangeSlider
 from .utils import ioff
+from .widgets import RangeSlider
 
 __all__ = [
     "decompose_bbox",
