@@ -1,10 +1,12 @@
+"""Functions that make some features in Matplotlib a bit more convenient."""
+
 from collections.abc import Iterable
 
+import numpy as np
 from matplotlib import interactive, is_interactive
 from matplotlib.pyplot import figure as mpl_figure
 from matplotlib.pyplot import install_repl_displayhook, rcParams, uninstall_repl_displayhook
 from numpy import abs, argmin, asarray, take
-import numpy as np
 
 __all__ = [
     "figure",
@@ -60,7 +62,7 @@ def figure(figsize=1, *args, **kwargs):
 def nearest_idx(array, value, axis=None):
     """
     Return the index of the array that is closest to value. Equivalent to
-    ``np.argmin(np.abs(array-value), axis=axis)``
+    `np.argmin(np.abs(array-value), axis=axis) <numpy.argmin>`.
 
     Parameters
     ----------
